Resolver

Struct Resolver 

pub struct Resolver { /* private fields */ }
An asynchronous DNS resolver, which returns results via callbacks.

Note that dropping the resolver will cause all outstanding requests to fail with result c_ares::Error::EDESTRUCTION.

Implementations

Source

impl Resolver

pub fn new() -> Result<Self, Error>

Create a new Resolver, using default Options.

pub fn with_options(options: Options) -> Result<Self, Error>

Create a new Resolver, with the given Options.

pub fn reinit(&self) -> Result<&Self>

Reinitialize a channel from system configuration.

pub fn set_servers<I, S>(&self, servers: I) -> Result<&Self>
where I: IntoIterator<Item = S>, S: AsRef<str>,

Set the list of servers to contact, instead of the servers specified in resolv.conf or the local named.

String format is host[:port]. IPv6 addresses with ports require square brackets eg [2001:4860:4860::8888]:53.

pub fn servers(&self) -> Vec<String>

Retrieves the list of configured servers.

Each entry is in host[:port] format, matching what set_servers accepts.

pub fn set_local_ipv4(&self, ipv4: Ipv4Addr) -> &Self

Set the local IPv4 address from which to make queries.

pub fn set_local_ipv6(&self, ipv6: Ipv6Addr) -> &Self

Set the local IPv6 address from which to make queries.

pub fn set_local_device(&self, device: &str) -> Result<&Self>

Set the local device from which to make queries.

pub fn set_sortlist<I, S>(&self, sortlist: I) -> Result<&Self>
where I: IntoIterator<Item = S>, S: AsRef<str>,

Initializes an address sortlist configuration, so that addresses returned by get_host_by_name() are sorted according to the sortlist.

Each element of the sortlist holds an IP-address/netmask pair. The netmask is optional but follows the address after a slash if present. For example: “130.155.160.0/255.255.240.0”, or “130.155.0.0”.

pub fn set_server_state_callback<F>(&self, callback: F) -> &Self
where F: Fn(&str, bool, ServerStateFlags) + Send + Sync + 'static,

Set a callback function to be invoked whenever a query on the channel completes.

callback(server, success, flags) will be called when a query completes.

  • server indicates the DNS server that was used for the query.
  • success indicates whether the query succeeded or not.
  • flags is a bitmask of flags describing various aspects of the query.
pub fn query_a<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<AResults>) + Send + 'static,

Look up the A records associated with name.

On completion, handler is called with the result.

pub fn search_a<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<AResults>) + Send + 'static,

Search for the A records associated with name.

On completion, handler is called with the result.

pub fn query_aaaa<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<AAAAResults>) + Send + 'static,

Look up the AAAA records associated with name.

On completion, handler is called with the result.

pub fn search_aaaa<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<AAAAResults>) + Send + 'static,

Search for the AAAA records associated with name.

On completion, handler is called with the result.

pub fn query_caa<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<CAAResults>) + Send + 'static,

Look up the CAA records associated with name.

On completion, handler is called with the result.

pub fn search_caa<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<CAAResults>) + Send + 'static,

Search for the CAA records associated with name.

On completion, handler is called with the result.

pub fn query_cname<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<CNameResults>) + Send + 'static,

Look up the CNAME records associated with name.

On completion, handler is called with the result.

pub fn search_cname<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<CNameResults>) + Send + 'static,

Search for the CNAME records associated with name.

On completion, handler is called with the result.

pub fn query_mx<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<MXResults>) + Send + 'static,

Look up the MX records associated with name.

On completion, handler is called with the result.

pub fn search_mx<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<MXResults>) + Send + 'static,

Search for the MX records associated with name.

On completion, handler is called with the result.

pub fn query_naptr<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<NAPTRResults>) + Send + 'static,

Look up the NAPTR records associated with name.

On completion, handler is called with the result.

pub fn search_naptr<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<NAPTRResults>) + Send + 'static,

Search for the NAPTR records associated with name.

On completion, handler is called with the result.

pub fn query_ns<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<NSResults>) + Send + 'static,

Look up the NS records associated with name.

On completion, handler is called with the result.

pub fn search_ns<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<NSResults>) + Send + 'static,

Search for the NS records associated with name.

On completion, handler is called with the result.

pub fn query_ptr<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<PTRResults>) + Send + 'static,

Look up the PTR records associated with name.

On completion, handler is called with the result.

pub fn search_ptr<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<PTRResults>) + Send + 'static,

Search for the PTR records associated with name.

On completion, handler is called with the result.

pub fn query_soa<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<SOAResult>) + Send + 'static,

Look up the SOA record associated with name.

On completion, handler is called with the result.

pub fn search_soa<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<SOAResult>) + Send + 'static,

Search for the SOA record associated with name.

On completion, handler is called with the result.

pub fn query_srv<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<SRVResults>) + Send + 'static,

Look up the SRV records associated with name.

On completion, handler is called with the result.

pub fn search_srv<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<SRVResults>) + Send + 'static,

Search for the SRV records associated with name.

On completion, handler is called with the result.

pub fn query_txt<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<TXTResults>) + Send + 'static,

Look up the TXT records associated with name.

On completion, handler is called with the result.

pub fn search_txt<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<TXTResults>) + Send + 'static,

Search for the TXT records associated with name.

On completion, handler is called with the result.

pub fn query_uri<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<URIResults>) + Send + 'static,

Look up the URI records associated with name.

On completion, handler is called with the result.

pub fn search_uri<F>(&self, name: &str, handler: F)
where F: FnOnce(Result<URIResults>) + Send + 'static,

Search for the URI records associated with name.

On completion, handler is called with the result.

pub fn get_host_by_address<F>(&self, address: &IpAddr, handler: F)
where F: FnOnce(Result<&HostResults>) + Send + 'static,

Perform a host query by address.

On completion, handler is called with the result.

pub fn get_host_by_name<F>(&self, name: &str, family: AddressFamily, handler: F)
where F: FnOnce(Result<&HostResults>) + Send + 'static,

Perform a host query by name.

On completion, handler is called with the result.

pub fn get_name_info<F>(&self, address: &SocketAddr, flags: NIFlags, handler: F)
where F: FnOnce(Result<NameInfoResult<'_>>) + Send + 'static,

Address-to-nodename translation in protocol-independent manner.

On completion, handler is called with the result.

pub fn get_addrinfo<F>( &self, name: &str, service: Option<&str>, hints: &AddrInfoHints, handler: F, )
where F: FnOnce(Result<AddrInfoResults>) + Send + 'static,

Initiate a host query by name and service.

On completion, handler is called with the result.

pub fn query<F>(&self, name: &str, dns_class: u16, query_type: u16, handler: F)
where F: FnOnce(Result<&[u8]>) + Send + 'static,

Initiate a single-question DNS query for name. The class and type of the query are per the provided parameters, taking values as defined in arpa/nameser.h.

On completion, handler is called with the result.

This method is provided so that users can query DNS types for which c-ares does not provide a parser; or in case a third-party parser is preferred. Usually, if a suitable query_xxx() is available, that should be used.

pub fn search<F>(&self, name: &str, dns_class: u16, query_type: u16, handler: F)
where F: FnOnce(Result<&[u8]>) + Send + 'static,

Initiate a series of single-question DNS queries for name. The class and type of the query are per the provided parameters, taking values as defined in arpa/nameser.h.

On completion, handler is called with the result.

This method is provided so that users can search DNS types for which c-ares does not provide a parser; or in case a third-party parser is preferred. Usually, if a suitable search_xxx() is available, that should be used.

pub fn send_dnsrec<F>(&self, dnsrec: &DnsRecord, handler: F) -> Result<u16>
where F: FnOnce(Result<&DnsRecord>) + Send + 'static,

Send a DNS query using a pre-built c_ares::DnsRecord.

On completion, handler is called with the result.

pub fn query_dnsrec<F>( &self, name: &str, dns_class: DnsCls, query_type: DnsRecordType, handler: F, ) -> Result<u16>
where F: FnOnce(Result<&DnsRecord>) + Send + 'static,

Initiate a DNS query for name with the given class and type, receiving a parsed c_ares::DnsRecord in the callback.

pub fn search_dnsrec<F>(&self, dnsrec: &DnsRecord, handler: F) -> Result<()>
where F: FnOnce(Result<&DnsRecord>) + Send + 'static,

Initiate a series of DNS queries using a pre-built c_ares::DnsRecord, receiving a parsed c_ares::DnsRecord in the callback.

pub fn queue_wait_empty(&self, timeout: Option<Duration>) -> Result<()>

Block until notified that there are no longer any queries in queue, or the specified timeout has expired.

Pass None to wait indefinitely.

pub fn queue_active_queries(&self) -> usize

Retrieve the total number of active queries pending answers from servers.

pub fn cancel(&self)

Cancel all requests made on this Resolver.